-- =============================================
-- SaveToDB Framework for Microsoft SQL Server
-- Version 7.19, March 12, 2018
--
-- Copyright 2015-2018 Gartle Technology Corporation
-- =============================================
GO

CREATE SCHEMA [savetodb_xls]
GO
CREATE SCHEMA [savetodb_dev]
GO
CREATE SCHEMA [savetodb_etl]
GO

print N'Schemas have been created';
GO

CREATE TABLE [savetodb_dev].[query_list] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_TYPE] [nvarchar](128) NOT NULL,
    [TABLE_CODE] [nvarchar](max),
    [INSERT_PROCEDURE] [nvarchar](max),
    [UPDATE_PROCEDURE] [nvarchar](max),
    [DELETE_PROCEDURE] [nvarchar](max),
    [PROCEDURE_TYPE] [nvarchar](128),
  CONSTRAINT [PK_query_list_savetodb_dev] PRIMARY KEY ([ID])
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.10, 2016-11-02
-- Description: SaveToDB Query List view
-- =============================================

CREATE VIEW [savetodb_dev].[view_query_list]
AS

SELECT
    s.name AS TABLE_SCHEMA
    , o.name AS TABLE_NAME
    , CASE o.[type] WHEN 'U' THEN 'BASE TABLE' WHEN 'V' THEN 'VIEW' WHEN 'P' THEN 'PROCEDURE' WHEN 'IF' THEN 'FUNCTION' ELSE o.type_desc END AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , COALESCE(q.INSERT_PROCEDURE, s.name + '.' + i.name) COLLATE DATABASE_DEFAULT AS INSERT_PROCEDURE
    , COALESCE(q.UPDATE_PROCEDURE, s.name + '.' + u.name) COLLATE DATABASE_DEFAULT AS UPDATE_PROCEDURE
    , COALESCE(q.DELETE_PROCEDURE, s.name + '.' + d.name) COLLATE DATABASE_DEFAULT AS DELETE_PROCEDURE
    , COALESCE(q.PROCEDURE_TYPE, CASE i.[type] WHEN 'P' THEN 'PROCEDURE' ELSE NULL END) AS PROCEDURE_TYPE
FROM
    sys.objects o
    INNER JOIN sys.schemas s ON s.[schema_id] = o.[schema_id]
    LEFT OUTER JOIN sys.procedures i ON i.[schema_id] = o.[schema_id] AND i.name = REPLACE(o.name, '_select', '') + '_insert'
        AND HAS_PERMS_BY_NAME('['+DB_NAME()+'].['+s.name+'].['+i.name+']', 'OBJECT', 'EXECUTE') = 1
    LEFT OUTER JOIN sys.procedures u ON u.[schema_id] = o.[schema_id] AND u.name = REPLACE(o.name, '_select', '') + '_update'
        AND HAS_PERMS_BY_NAME('['+DB_NAME()+'].['+s.name+'].['+u.name+']', 'OBJECT', 'EXECUTE') = 1
    LEFT OUTER JOIN sys.procedures d ON d.[schema_id] = o.[schema_id] AND d.name = REPLACE(o.name, '_select', '') + '_delete'
        AND HAS_PERMS_BY_NAME('['+DB_NAME()+'].['+s.name+'].['+d.name+']', 'OBJECT', 'EXECUTE') = 1
    LEFT OUTER JOIN [savetodb_dev].[query_list] q ON q.TABLE_SCHEMA = s.name COLLATE DATABASE_DEFAULT AND q.TABLE_NAME = o.name COLLATE DATABASE_DEFAULT
WHERE
    o.[type] IN ('U', 'V', 'P', 'IF')
    AND (HAS_PERMS_BY_NAME(db_name()+'.['+s.name+'].['+o.name+']', 'OBJECT', 'SELECT') = 1
        OR HAS_PERMS_BY_NAME(db_name()+'.['+s.name+'].['+o.name+']', 'OBJECT', 'EXECUTE') = 1)
    AND NOT (s.name = 'dbo' AND (o.name LIKE 'sp_%' OR o.name LIKE 'fn_%' OR o.name LIKE 'sys%'))
    AND NOT s.name IN ('savetodb_etl')
    AND NOT o.name LIKE '%_insert'
    AND NOT o.name LIKE '%_update'
    AND NOT o.name LIKE '%_delete'
    AND NOT o.name LIKE '%_merge'
    AND NOT o.name LIKE '%_change'

UNION ALL
SELECT
    DISTINCT
    q.TABLE_SCHEMA COLLATE DATABASE_DEFAULT AS TABLE_SCHEMA
    , q.TABLE_NAME COLLATE DATABASE_DEFAULT AS TABLE_NAME
    , q.TABLE_TYPE COLLATE DATABASE_DEFAULT AS TABLE_TYPE
    , q.TABLE_CODE
    , q.INSERT_PROCEDURE COLLATE DATABASE_DEFAULT AS INSERT_PROCEDURE
    , q.UPDATE_PROCEDURE COLLATE DATABASE_DEFAULT AS UPDATE_PROCEDURE
    , q.DELETE_PROCEDURE COLLATE DATABASE_DEFAULT AS DELETE_PROCEDURE
    , q.PROCEDURE_TYPE
FROM
    [savetodb_dev].[query_list] q
    LEFT OUTER JOIN sys.schemas s ON s.name = q.TABLE_SCHEMA COLLATE DATABASE_DEFAULT
    LEFT OUTER JOIN sys.objects t ON t.[schema_id] = s.[schema_id] AND t.name = q.TABLE_NAME COLLATE DATABASE_DEFAULT
WHERE
    q.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND t.[object_id] IS NULL

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.9, 2016-06-21
-- Description: SaveToDB Query List view
--
-- This view can be used as a data source of other Query List views
-- which can filter different logic areas of a database.
-- =============================================

CREATE VIEW [savetodb_xls].[view_query_list]
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , t.TABLE_CODE
    , t.INSERT_PROCEDURE
    , t.UPDATE_PROCEDURE
    , t.DELETE_PROCEDURE
    , t.PROCEDURE_TYPE
FROM
    [savetodb_dev].[view_query_list] t
WHERE
    NOT t.TABLE_SCHEMA IN ('etl01', 'dbo01', 'xls01', 'savetodb_dev', 'savetodb_xls', 'SAVETODB_DEV', 'SAVETODB_XLS')
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI IN (
          'viewColumnTranslation'
        , 'viewObjectTranslation'
        , 'viewEventHandlers'
        , 'viewParameterValues'
        , 'viewTableFormats'
        , 'view_column_translation'
        , 'view_object_translation'
        , 'view_event_handlers'
        , 'view_parameter_values'
        , 'view_table_formats'
        )
    AND NOT t.TABLE_NAME LIKE 'viewQueryList%'
    AND NOT t.TABLE_NAME LIKE 'viewParameterValues%'
    AND NOT t.TABLE_NAME LIKE 'viewValidationList%'
    AND NOT t.TABLE_NAME LIKE 'uspExcelEvent%'
    AND NOT t.TABLE_NAME LIKE 'uspParameterValues%'
    AND NOT t.TABLE_NAME LIKE 'uspValidationList%'
    AND NOT t.TABLE_NAME LIKE 'ufnExcelEvent%'
    AND NOT t.TABLE_NAME LIKE 'ufnParameterValues%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'view_query_list%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'xl_%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'view_xl_%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'usp_xl_%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'ufn_xl_%'

GO

print N'QueryList objects have been created';
GO

CREATE TABLE [savetodb_dev].[column_translation] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128),
    [COLUMN_NAME] [nvarchar](128) NOT NULL,
    [LANGUAGE_NAME] [char](2) NOT NULL,
    [TRANSLATED_NAME] [nvarchar](128),
    [TRANSLATED_DESC] [nvarchar](1024),
  CONSTRAINT [PK_column_translation_savetodb_dev] PRIMARY KEY ([ID])
)

GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_column_translation_schema_name_column_language_savetodb_dev] ON [savetodb_dev].[column_translation]
(
    [TABLE_SCHEMA],
    [TABLE_NAME],
    [COLUMN_NAME],
    [LANGUAGE_NAME]
)
GO

CREATE TABLE [savetodb_dev].[object_translation] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [LANGUAGE_NAME] [char](2) NOT NULL,
    [TRANSLATED_NAME] [nvarchar](128),
    [TRANSLATED_DESC] [nvarchar](255),
    [TRANSLATED_COMMENT] [nvarchar](4000),
  CONSTRAINT [PK_object_translation_savetodb_dev] PRIMARY KEY ([ID])
)

GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_object_translation_schema_name_language_savetodb_dev] ON [savetodb_dev].[object_translation]
(
    [TABLE_SCHEMA],
    [TABLE_NAME],
    [LANGUAGE_NAME]
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Configuration view of column and parameter translation
-- =============================================

CREATE VIEW [savetodb_xls].[view_column_translation]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME
    , t.LANGUAGE_NAME
    , t.TRANSLATED_NAME
    , t.TRANSLATED_DESC
FROM
    [savetodb_dev].[column_translation] t

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.2, 2015-05-12
-- Description: Configuration view of object translation
-- =============================================

CREATE VIEW [savetodb_xls].[view_object_translation]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.LANGUAGE_NAME
    , t.TRANSLATED_NAME
    , t.TRANSLATED_DESC
    , t.TRANSLATED_COMMENT
FROM
    [savetodb_dev].[object_translation] t

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.9, 2016-06-21
-- Description: Object descriptions for users
-- =============================================

CREATE VIEW [savetodb_xls].[view_object_description]
AS

SELECT
    t.ID
    , t.LANGUAGE_NAME
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TRANSLATED_NAME
    , t.TRANSLATED_COMMENT
FROM
    [savetodb_xls].[view_query_list] q
    INNER JOIN [savetodb_dev].[object_translation] t ON t.TABLE_SCHEMA = q.TABLE_SCHEMA AND t.TABLE_NAME = q.TABLE_NAME
WHERE
    t.TRANSLATED_NAME IS NOT NULL
    AND t.TRANSLATED_COMMENT IS NOT NULL

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.8, 2016-05-27
-- Description: The procedure inserts column translation for new objects
-- =============================================

CREATE PROCEDURE [savetodb_etl].[usp_update_column_translation]
    @schema nvarchar(128) = NULL
    , @language_name char(2) = NULL
AS
BEGIN

IF @language_name IS NULL
    BEGIN
    SELECT 'Specify @language_name parameter' AS [message]
    RETURN
    END

SET NOCOUNT ON

INSERT INTO [savetodb_dev].[column_translation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME
    , @language_name AS LANGUAGE_NAME
    , t.COLUMN_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (   
    SELECT
        t.TABLE_SCHEMA
        , t.TABLE_NAME
        , t.TABLE_TYPE
        , c.COLUMN_NAME
        , c.ORDINAL_POSITION
    FROM
        INFORMATION_SCHEMA.COLUMNS c
        INNER JOIN INFORMATION_SCHEMA.TABLES t
            ON t.TABLE_SCHEMA = c.TABLE_SCHEMA AND t.TABLE_NAME = c.TABLE_NAME
    WHERE
        (t.TABLE_TYPE = 'BASE TABLE' OR t.TABLE_TYPE = 'VIEW')  -- User tables and views only
        AND t.TABLE_SCHEMA = COALESCE(@schema, t.TABLE_SCHEMA)
        AND NOT t.TABLE_NAME IN (
            'object_translation'
            , 'column_translation'
            , 'parameter_values'
            , 'event_handlers'
            , 'table_formats'
            , 'query_list'

            , 'view_query_list'
            , 'view_event_handlers'
            , 'view_column_translation'
            , 'view_object_translation'
            , 'view_parameter_values'
            , 'view_table_formats'
            , 'view_object_translation_suggest'
            , 'view_event_handlers_suggest'
            , 'view_object_description'

            , 'usp_update_table_format'
            , 'usp_generate_edit_procedures'
            , 'usp_update_column_translation'
            , 'usp_update_column_translation_group'
            , 'usp_update_object_translation'
            , 'usp_update_object_translation_absent'
            , 'usp_update_event_handlers'
            )
        AND NOT t.TABLE_NAME LIKE 'view_parameter_values_%'
        AND NOT t.TABLE_NAME LIKE 'view_validation_list_%'
        AND NOT t.TABLE_NAME LIKE 'view_xl_%'
        AND NOT t.TABLE_NAME LIKE 'xl_%'
        AND NOT t.TABLE_SCHEMA LIKE 'etl%'

    UNION ALL
        
    SELECT
        p.ROUTINE_SCHEMA AS TABLE_SCHEMA
        , p.ROUTINE_NAME AS TABLE_NAME
        , p.ROUTINE_TYPE AS TABLE_TYPE
        , REPLACE(c.PARAMETER_NAME, '@', '') AS COLUMN_NAME
        , c.ORDINAL_POSITION
    FROM
        INFORMATION_SCHEMA.PARAMETERS c
        INNER JOIN INFORMATION_SCHEMA.ROUTINES p
            ON p.SPECIFIC_SCHEMA = c.SPECIFIC_SCHEMA AND p.SPECIFIC_NAME = c.SPECIFIC_NAME
    WHERE
        p.ROUTINE_TYPE = 'PROCEDURE'
        AND p.ROUTINE_SCHEMA = COALESCE(@schema, p.ROUTINE_SCHEMA)
        AND NOT p.ROUTINE_NAME LIKE 'sp_%'                      -- System procedures 
        AND c.PARAMETER_MODE LIKE 'IN%'                         -- Input parameters only
        AND NOT p.ROUTINE_SCHEMA LIKE 'etl%'                    -- Service schema
        AND NOT p.ROUTINE_NAME LIKE 'usp%_insert'               -- Hidden procedures for INSERT
        AND NOT p.ROUTINE_NAME LIKE 'usp%_update'               -- Hidden procedures for UPDATE
        AND NOT p.ROUTINE_NAME LIKE 'usp%_delete'               -- Hidden procedures for DELETE
        AND NOT p.ROUTINE_NAME LIKE 'usp%_merge'                -- Hidden procedures for MERGE
        AND NOT p.ROUTINE_NAME LIKE 'usp%_change'               -- Hidden procedures used as CHANGE event handlers
        AND NOT p.ROUTINE_NAME LIKE 'usp_excel_event_%'         -- Hidden procedures for Excel Event Handling
        AND NOT p.ROUTINE_NAME LIKE 'usp_parameter_values%'     -- Service procedures for parameter values
        AND NOT p.ROUTINE_NAME LIKE 'usp_validation_List%'      -- Service procedures for validation lists
        AND NOT p.ROUTINE_NAME = 'usp_generate_edit_procedures' -- Service procedure for edit procedure generation
        AND NOT p.ROUTINE_NAME LIKE 'usp_update_translation_%'  -- Service procedures for translation
    ) t

    LEFT OUTER JOIN [savetodb_dev].[column_translation] o
        ON o.TABLE_SCHEMA = t.TABLE_SCHEMA COLLATE DATABASE_DEFAULT AND o.TABLE_NAME = t.TABLE_NAME COLLATE DATABASE_DEFAULT
            AND o.COLUMN_NAME = t.COLUMN_NAME COLLATE DATABASE_DEFAULT
            AND o.LANGUAGE_NAME = @language_name
WHERE
    o.TABLE_SCHEMA IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [message]

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.8, 2016-05-27
-- Description: The procedure inserts column translation for new columns and parameters
-- =============================================

CREATE PROCEDURE [savetodb_etl].[usp_update_column_translation_group]
    @schema nvarchar(128) = NULL
    , @language_name char(2) = NULL
AS
BEGIN

IF @language_name IS NULL
    BEGIN
    SELECT 'Specify @language_name parameter' AS [message]
    RETURN
    END

SET NOCOUNT ON

INSERT INTO [savetodb_dev].[column_translation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , NULL AS TABLE_NAME
    , t.COLUMN_NAME
    , @language_name AS LANGUAGE_NAME
    , t.COLUMN_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (
        SELECT
            t.TABLE_SCHEMA
            , t.COLUMN_NAME
        FROM
            (   
                SELECT
                    t.TABLE_SCHEMA
                    , t.TABLE_NAME
                    , t.TABLE_TYPE
                    , c.COLUMN_NAME
                    , c.ORDINAL_POSITION
                FROM
                    INFORMATION_SCHEMA.COLUMNS c
                    INNER JOIN INFORMATION_SCHEMA.TABLES t
                        ON t.TABLE_SCHEMA = c.TABLE_SCHEMA AND t.TABLE_NAME = c.TABLE_NAME
                WHERE
                    (t.TABLE_TYPE = 'BASE TABLE' OR t.TABLE_TYPE = 'VIEW')  -- User tables and views only
                    AND t.TABLE_SCHEMA = COALESCE(@schema, t.TABLE_SCHEMA)
                    AND NOT t.TABLE_NAME IN (
                        'object_translation'
                        , 'column_translation'
                        , 'parameter_values'
                        , 'event_handlers'
                        , 'table_formats'
                        , 'query_list'

                        , 'view_query_list'
                        , 'view_event_handlers'
                        , 'view_column_translation'
                        , 'view_object_translation'
                        , 'view_parameter_values'
                        , 'view_table_formats'
                        , 'view_object_translation_suggest'
                        , 'view_event_handlers_suggest'
                        , 'view_object_description'

                        , 'usp_update_table_format'
                        , 'usp_generate_edit_procedures'
                        , 'usp_update_column_translation'
                        , 'usp_update_column_translation_group'
                        , 'usp_update_object_translation'
                        , 'usp_update_object_translation_absent'
                        , 'usp_update_event_handlers'
                        )
                    AND NOT t.TABLE_NAME LIKE 'view_parameter_values_%'
                    AND NOT t.TABLE_NAME LIKE 'view_validation_list_%'
                    AND NOT t.TABLE_NAME LIKE 'view_xl_%'
                    AND NOT t.TABLE_NAME LIKE 'xl_%'
                    AND NOT t.TABLE_SCHEMA LIKE 'etl%'

                UNION ALL
            
                SELECT
                    p.ROUTINE_SCHEMA AS TABLE_SCHEMA
                    , p.ROUTINE_NAME AS TABLE_NAME
                    , p.ROUTINE_TYPE AS TABLE_TYPE
                    , REPLACE(c.PARAMETER_NAME, '@', '') AS COLUMN_NAME
                    , c.ORDINAL_POSITION
                FROM
                    INFORMATION_SCHEMA.PARAMETERS c
                    INNER JOIN INFORMATION_SCHEMA.ROUTINES p
                        ON p.SPECIFIC_SCHEMA = c.SPECIFIC_SCHEMA AND p.SPECIFIC_NAME = c.SPECIFIC_NAME
                WHERE
                    p.ROUTINE_TYPE = 'PROCEDURE'
                    AND p.ROUTINE_SCHEMA = COALESCE(@schema, p.ROUTINE_SCHEMA)
                    AND NOT p.ROUTINE_NAME LIKE 'sp_%'                      -- System procedures 
                    AND c.PARAMETER_MODE LIKE 'IN%'                         -- Input parameters only
                    AND NOT p.ROUTINE_SCHEMA LIKE 'etl%'                    -- Service schema
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_insert'               -- Hidden procedures for INSERT
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_update'               -- Hidden procedures for UPDATE
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_delete'               -- Hidden procedures for DELETE
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_merge'                -- Hidden procedures for MERGE
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_change'               -- Hidden procedures used as CHANGE event handlers
                    AND NOT p.ROUTINE_NAME LIKE 'usp_excel_event_%'         -- Hidden procedures for Excel Event Handling
                    AND NOT p.ROUTINE_NAME LIKE 'usp_parameter_values%'     -- Service procedures for parameter values
                    AND NOT p.ROUTINE_NAME LIKE 'usp_validation_List%'      -- Service procedures for validation lists
                    AND NOT p.ROUTINE_NAME = 'usp_generate_edit_procedures' -- Service procedure for edit procedure generation
                    AND NOT p.ROUTINE_NAME LIKE 'usp_update_translation_%'  -- Service procedures for translation
            ) t
        GROUP BY
            t.TABLE_SCHEMA
            , t.COLUMN_NAME
    ) t
    LEFT OUTER JOIN [savetodb_dev].[column_translation] o
        ON UPPER(o.TABLE_SCHEMA) = UPPER(t.TABLE_SCHEMA) COLLATE DATABASE_DEFAULT AND o.TABLE_NAME IS NULL
            AND UPPER(o.COLUMN_NAME) = UPPER(t.COLUMN_NAME) COLLATE DATABASE_DEFAULT
            AND UPPER(o.LANGUAGE_NAME) = UPPER(@language_name)
WHERE
    o.COLUMN_NAME IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [message]

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.8, 2016-05-27
-- Description: The procedure inserts translation for new objects
-- =============================================

CREATE PROCEDURE [savetodb_etl].[usp_update_object_translation]
    @schema nvarchar(128) = NULL
    , @language_name char(2) = NULL
AS
BEGIN

IF @language_name IS NULL
    BEGIN
    SELECT 'Specify @language_name parameter' AS [message]
    RETURN
    END

SET NOCOUNT ON

INSERT INTO [savetodb_dev].[object_translation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , @language_name AS LANGUAGE_NAME
    , t.TABLE_SCHEMA + '.' + t.TABLE_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (   
        SELECT
            t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.TABLES t
        WHERE
            (t.TABLE_TYPE = 'BASE TABLE' OR t.TABLE_TYPE = 'VIEW')
            AND t.TABLE_SCHEMA = COALESCE(@schema, t.TABLE_SCHEMA)
            AND NOT (
                t.TABLE_NAME LIKE 'view_parameter_values_%'
                OR t.TABLE_NAME LIKE 'view_validation_list_%'
                OR t.TABLE_NAME LIKE 'view_xl_%'
                OR t.TABLE_NAME LIKE 'xl_%'
            )

        UNION ALL
        
        SELECT
            p.ROUTINE_SCHEMA AS TABLE_SCHEMA
            , p.ROUTINE_NAME AS TABLE_NAME
            , p.ROUTINE_TYPE AS TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.ROUTINES p
        WHERE
            p.ROUTINE_TYPE = 'PROCEDURE'
            AND p.ROUTINE_SCHEMA = COALESCE(@schema, p.ROUTINE_SCHEMA)
            AND NOT (
                p.ROUTINE_NAME LIKE 'usp_parameter_values_%'
                OR p.ROUTINE_NAME LIKE 'usp_excel_event_%'
                OR p.ROUTINE_NAME LIKE 'usp_validation_list_%'
                OR p.ROUTINE_NAME LIKE 'usp_xl_%'
                OR p.ROUTINE_NAME LIKE 'xl_%'
            )
    ) t
    LEFT OUTER JOIN [savetodb_dev].[object_translation] o
        ON UPPER(o.TABLE_SCHEMA) = UPPER(t.TABLE_SCHEMA) COLLATE DATABASE_DEFAULT AND UPPER(o.TABLE_NAME) = UPPER(t.TABLE_NAME) COLLATE DATABASE_DEFAULT
            AND UPPER(o.LANGUAGE_NAME) = UPPER(@language_name)
WHERE
    o.TABLE_SCHEMA IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [message]

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.8, 2016-05-27
-- Description: The procedure inserts translation of existing languages for absent objects
-- =============================================

CREATE PROCEDURE [savetodb_etl].[usp_update_object_translation_absent]
AS
BEGIN

SET NOCOUNT ON

INSERT INTO [savetodb_dev].[object_translation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , l.LANGUAGE_NAME
    , t.TABLE_SCHEMA + '.' + t.TABLE_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (   
        SELECT
            t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.TABLES t
        WHERE
            (t.TABLE_TYPE = 'BASE TABLE'
            OR t.TABLE_TYPE = 'VIEW')
            AND NOT (
                t.TABLE_NAME LIKE 'view_parameter_values_%'
                OR t.TABLE_NAME LIKE 'view_validation_list_%'
                OR t.TABLE_NAME LIKE 'view_xl_%'
                OR t.TABLE_NAME LIKE 'xl_%'
            )

        UNION ALL
        
        SELECT
            p.ROUTINE_SCHEMA AS TABLE_SCHEMA
            , p.ROUTINE_NAME AS TABLE_NAME
            , p.ROUTINE_TYPE AS TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.ROUTINES p
        WHERE
            p.ROUTINE_TYPE = 'PROCEDURE'
            AND NOT (
                p.ROUTINE_NAME LIKE 'usp_parameter_values_%'
                OR p.ROUTINE_NAME LIKE 'usp_excel_event_%'
                OR p.ROUTINE_NAME LIKE 'usp_validation_list_%'
                OR p.ROUTINE_NAME LIKE 'usp_xl_%'
                OR p.ROUTINE_NAME LIKE 'xl_%'
            )
    ) t
    INNER JOIN (
        SELECT
            DISTINCT
            TABLE_SCHEMA
            , LANGUAGE_NAME
        FROM
            [savetodb_dev].[object_translation]
    ) l ON l.TABLE_SCHEMA = t.TABLE_SCHEMA COLLATE DATABASE_DEFAULT
    LEFT OUTER JOIN [savetodb_dev].[object_translation] o
        ON o.TABLE_SCHEMA = t.TABLE_SCHEMA COLLATE DATABASE_DEFAULT AND o.TABLE_NAME = t.TABLE_NAME COLLATE DATABASE_DEFAULT
            AND o.LANGUAGE_NAME = l.LANGUAGE_NAME
WHERE
    o.TABLE_SCHEMA IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [message]

END
GO

print N'Translation objects have been created';
GO

CREATE TABLE [savetodb_dev].[event_handlers] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [COLUMN_NAME] [nvarchar](128),
    [EVENT_NAME] [varchar](50) NOT NULL,
    [HANDLER_SCHEMA] [nvarchar](128),
    [HANDLER_NAME] [nvarchar](128),
    [HANDLER_TYPE] [nvarchar](128),
    [HANDLER_CODE] [nvarchar](max),
    [TARGET_WORKSHEET] [nvarchar](128),
    [MENU_ORDER] [int],
    [EDIT_PARAMETERS] [bit],
    [IS_ACTIVE] [bit],
  CONSTRAINT [PK_event_handlers_savetodb_dev] PRIMARY KEY ([ID])
)

GO
ALTER TABLE [savetodb_dev].[event_handlers] ADD  CONSTRAINT [DF_event_handlers_IS_ACTIVE]  DEFAULT ((1)) FOR [IS_ACTIVE]
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Configuration view of event handlers
-- =============================================

CREATE VIEW [savetodb_xls].[view_event_handlers]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME
    , t.EVENT_NAME
    , t.HANDLER_SCHEMA
    , t.HANDLER_NAME
    , t.HANDLER_TYPE
    , t.HANDLER_CODE
    , t.TARGET_WORKSHEET
    , t.MENU_ORDER
    , t.EDIT_PARAMETERS
FROM
    [savetodb_dev].[event_handlers] t
WHERE
    t.IS_ACTIVE = 1

GO

print N'EventHandlers objects have been created';
GO

CREATE TABLE [savetodb_dev].[parameter_values] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [PARAMETER_NAME] [nvarchar](128) NOT NULL,
    [SELECT_SCHEMA] [nvarchar](128),
    [SELECT_NAME] [nvarchar](128) NOT NULL,
    [SELECT_TYPE] [nvarchar](128),
    [SELECT_CODE] [nvarchar](max),
  CONSTRAINT [PK_parameter_values_savetodb_dev] PRIMARY KEY ([ID])
)

GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_parameter_values_schema_name_parameter_savetodb_dev] ON [savetodb_dev].[parameter_values]
(
    [TABLE_SCHEMA],
    [TABLE_NAME],
    [PARAMETER_NAME]
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Configuration view of queries of parameter values
-- =============================================

CREATE VIEW [savetodb_xls].[view_parameter_values]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.PARAMETER_NAME
    , t.SELECT_SCHEMA
    , t.SELECT_NAME
    , t.SELECT_TYPE
    , t.SELECT_CODE
FROM
    [savetodb_dev].[parameter_values] t

GO

print N'ParameterValues  objects have been created';
GO

CREATE TABLE [savetodb_dev].[table_formats] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_EXCEL_FORMAT_XML] [xml],
  CONSTRAINT [PK_TableFormat_savetodb_dev] PRIMARY KEY ([ID])
)

GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_table_formats_schema_name_savetodb_dev] ON [savetodb_dev].[table_formats]
(
    [TABLE_NAME],
    [TABLE_SCHEMA]
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Configuration view of Excel formats of database objects
-- =============================================

CREATE VIEW [savetodb_xls].[view_table_formats]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_EXCEL_FORMAT_XML
FROM
    [savetodb_dev].[table_formats] t

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.9, 2015-06-13
-- Description: The procedure updates Excel table formats
-- =============================================

CREATE PROCEDURE [savetodb_dev].[usp_update_table_format]
    @Schema nvarchar(128) = NULL
    , @Name nvarchar(128) = NULL
    , @ExcelFormatXML xml = NULL
AS
BEGIN

SET NOCOUNT ON

IF @Schema IS NOT NULL AND @Name IS NOT NULL
    IF @ExcelFormatXML IS NULL
        BEGIN

        DELETE [savetodb_dev].[table_formats]
        WHERE
            TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name

        END
    ELSE
        BEGIN

        UPDATE [savetodb_dev].[table_formats]
        SET
            TABLE_EXCEL_FORMAT_XML = @ExcelFormatXML
        WHERE
            TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name

        IF @@ROWCOUNT = 0
            INSERT [savetodb_dev].[table_formats]
                (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML)
            VALUES
                (@Schema, @Name, @ExcelFormatXML)

        END
                
END
GO

print N'TableFormats objects have been created';
GO

CREATE ROLE [savetodb_dev_role]
GO
CREATE ROLE [savetodb_xls_role]
GO

GRANT SELECT, EXECUTE, INSERT, UPDATE, DELETE, VIEW DEFINITION ON SCHEMA::[savetodb_dev] TO [savetodb_dev_role]
GO
GRANT SELECT, EXECUTE, VIEW DEFINITION ON SCHEMA::[savetodb_etl] TO [savetodb_dev_role]
GO
GRANT SELECT, EXECUTE, VIEW DEFINITION ON SCHEMA::[savetodb_xls] TO [savetodb_dev_role]
GO
GRANT SELECT, EXECUTE ON SCHEMA::[savetodb_xls] TO [savetodb_xls_role]
GO

print N'Roles have been created';
GO

SET NOCOUNT ON;

INSERT INTO [savetodb_dev].[query_list] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'savetodb_xls', N'view_table_formats',      N'VIEW', NULL, N'savetodb_dev.table_formats', N'savetodb_dev.table_formats', N'savetodb_dev.table_formats', N'TABLE');
INSERT INTO [savetodb_dev].[query_list] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'savetodb_xls', N'view_parameter_values',   N'VIEW', NULL, N'savetodb_dev.parameter_values', N'savetodb_dev.parameter_values', N'savetodb_dev.parameter_values', N'TABLE');
INSERT INTO [savetodb_dev].[query_list] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'savetodb_xls', N'view_event_handlers',     N'VIEW', NULL, N'savetodb_dev.event_handlers', N'savetodb_dev.event_handlers', N'savetodb_dev.event_handlers', N'TABLE');
INSERT INTO [savetodb_dev].[query_list] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'savetodb_xls', N'view_object_description', N'VIEW', NULL, N'savetodb_dev.object_translation', N'savetodb_dev.object_translation', N'savetodb_dev.object_translation', N'TABLE');
INSERT INTO [savetodb_dev].[query_list] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'savetodb_xls', N'view_object_translation', N'VIEW', NULL, N'savetodb_dev.object_translation', N'savetodb_dev.object_translation', N'savetodb_dev.object_translation', N'TABLE');
INSERT INTO [savetodb_dev].[query_list] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'savetodb_xls', N'view_column_translation', N'VIEW', NULL, N'savetodb_dev.column_translation', N'savetodb_dev.column_translation', N'savetodb_dev.column_translation', N'TABLE');

INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'column_translation', NULL, N'Actions', N'savetodb_etl', N'usp_update_column_translation', N'PROCEDURE', NULL, N'_Reload', 1, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'column_translation', NULL, N'Actions', N'savetodb_etl', N'usp_update_column_translation_group', N'PROCEDURE', NULL, N'_Reload', 2, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'column_translation', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'column_translation', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-translation.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'object_translation', NULL, N'Actions', N'savetodb_etl', N'usp_update_object_translation_absent', N'PROCEDURE', NULL, N'_Reload', 1, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'object_translation', NULL, N'Actions', N'savetodb_etl', N'usp_update_object_translation', N'PROCEDURE', NULL, N'_Reload', 2, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'object_translation', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'object_translation', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-translation.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'event_handlers', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-event-handlers.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'parameter_values', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-parameter-values.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'query_list', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-query-list.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'table_formats', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-table-formats.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_column_translation', NULL, N'Actions', N'savetodb_etl', N'usp_update_column_translation', N'PROCEDURE', NULL, N'_Reload', 1, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_column_translation', NULL, N'Actions', N'savetodb_etl', N'usp_update_column_translation_group', N'PROCEDURE', NULL, N'_Reload', 2, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_column_translation', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_column_translation', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-translation.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_object_translation', NULL, N'Actions', N'savetodb_etl', N'usp_update_object_translation_absent', N'PROCEDURE', NULL, N'_Reload', 1, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_object_translation', NULL, N'Actions', N'savetodb_etl', N'usp_update_object_translation', N'PROCEDURE', NULL, N'_Reload', 2, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_object_translation', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_object_translation', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-translation.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_event_handlers', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-event-handlers.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_parameter_values', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-parameter-values.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_dev', N'view_query_list', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-query-list.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_query_list', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-query-list.htm', NULL, 11, NULL, 1);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'savetodb_xls', N'view_table_formats', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/savetodb/configuring-table-formats.htm', NULL, 11, NULL, 1);

INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_dev', N'query_list', N'TABLE_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_dev', N'query_list', N'PROCEDURE_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_dev', N'event_handlers', N'EVENT_NAME', N'ValidationList', NULL, N'', N'VALUES', N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_dev', N'event_handlers', N'HANDLER_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_dev', N'parameter_values', N'SELECT_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_xls', N'view_query_list', N'TABLE_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_xls', N'view_query_list', N'PROCEDURE_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_xls', N'view_event_handlers', N'EVENT_NAME', N'ValidationList', NULL, N'', N'VALUES', N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_xls', N'view_event_handlers', N'HANDLER_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_xls', N'view_parameter_values', N'SELECT_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_dev', N'event_handlers', N'HANDLER_CODE', N'DoNotConvertFormulas', NULL, N'', NULL, NULL);
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (N'savetodb_xls', N'view_event_handlers', N'HANDLER_CODE', N'DoNotConvertFormulas', NULL, N'', NULL, NULL);

INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_dev', N'column_translation', 'en', NULL, N'Configuration Table of Column Translation', N'The table defines translation for Excel table headers and ribbon fields');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_dev', N'event_handlers', 'en', NULL, N'Configuration Table of Excel Event Handlers', N'The table defines Excel event handlers and Actions and Context Menu items');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_dev', N'object_translation', 'en', NULL, N'Configuration Table of Object Translation', N'The table defines translation for Query List, Actions and Context Menu items');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_dev', N'parameter_values', 'en', NULL, N'Configuration Table of Parameter Value Queries', N'The table defines objects to select ribbon parameter values');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_dev', N'query_list', 'en', NULL, N'Configuration Table of Query List', N'The table defines configuration of Query List objects');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_dev', N'table_formats', 'en', NULL, N'Configuration Table of Excel Table Formats', N'The table contains Excel formats of database objects');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_dev', N'usp_update_table_format', 'en', NULL, N'Configuration Procedure to Save Table Formats', N'The procedure is used to save Excel formats of database objects');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_dev', N'view_query_list', N'en', N'Base Framework Query List', N'Configuration View of Query List with All Database Objects', N'The view selects all the database objects and is used as a source for other query list views');

INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_etl', N'usp_update_column_translation', 'en', N'Add Column Translation', N'Procedure to Insert Column Translations', N'The procedure is used to insert new column translation data into the column_translation table.');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_etl', N'usp_update_column_translation_group', 'en', N'Add Column Group Translation', N'Procedure to Insert Column Group Translations', N'The procedure is used to insert new translation data for group of columns and parameters into the column_translation table.');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_etl', N'usp_update_event_handlers', 'en', NULL, N'Procedure to Insert Event Handlers', N'The procedure is used to insert new event handler data into the event_handlers table from view_event_handlers_suggest.');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_etl', N'usp_update_object_translation', 'en', N'Add New Schema or Language Translation', N'Procedure to Insert New Schema or Language Object Translation', N'The procedure is used to insert translation data for new schemas or languages into the object_translation table.');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_etl', N'usp_update_object_translation_absent', 'en', N'Add New Object Translation', N'Procedure to Insert New Object Translation of Existing Schema and Languages', N'The procedure is used to insert translation data for new objects of existing schemas and languages into
the object_translation table. view_object_translation_suggest is used as a data source.');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_etl', N'view_event_handlers_suggest', 'en', NULL, N'Data to Insert into event_handlers Table', N'This view suggests possible new Excel event handlers based on a table relation analysis.');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_etl', N'view_object_translation_suggest', 'en', NULL, N'Data to Insert into object_translation Table', N'This view selects database objects that have no translation data in the object_translation table.
The usp_update_object_translation_absent procedure is used to insert the data into the object_translation table.');

INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_xls', N'view_column_translation', N'en', NULL, N'Configuration View of Column Translation', N'The view selects column translation data used by the SaveToDB add-in');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_xls', N'view_event_handlers', N'en', NULL, N'Configuration View of Excel Event Handlers', N'The view selects event handler configurations used by the SaveToDB add-in');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_xls', N'view_object_description', N'en', N'Object Descriptions', N'Database Object Descriptions', N'You may use Query List to connect to these objects');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_xls', N'view_object_translation', N'en', NULL, N'Configuration View of Object Translation', N'The view selects object translation data used by the SaveToDB add-in');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_xls', N'view_parameter_values', N'en', NULL, N'Configuration View of Parameter Value Queries', N'The view selects parameter configurations used by the SaveToDB add-in');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_xls', N'view_query_list', N'en', N'Framework Query List', N'Configuration View of Query List', N'The view selects a database object list used by the SaveToDB add-in');
INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'savetodb_xls', N'view_table_formats', N'en', NULL, N'Configuration View of Excel Table Formats', N'The view selects saved table formats used by the SaveToDB add-in');

INSERT INTO [savetodb_dev].[object_translation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'http01', N'Online Help', N'en', N'Online Help', NULL, NULL);

INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'column_translation', N'COLUMN_NAME', 'en', NULL, N'Column or parameter name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'column_translation', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'column_translation', N'LANGUAGE_NAME', 'en', NULL, N'Two-char language code');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'column_translation', N'TABLE_NAME', 'en', NULL, N'Database object name or NULL for entire schema scope');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'column_translation', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema or NULL for entire database scope');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'column_translation', N'TRANSLATED_DESC', 'en', NULL, N'Text for Excel table header comments and ribbon parameter SuperTips');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'column_translation', N'TRANSLATED_NAME', 'en', NULL, N'Translated name for Excel table headers and ribbon parameters');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'COLUMN_NAME', 'en', NULL, N'Column name or NULL to use the handler for entire table');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'EDIT_PARAMETERS', 'en', NULL, N'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'EVENT_NAME', 'en', NULL, N'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'HANDLER_NAME', 'en', NULL, N'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'HANDLER_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'HANDLER_TYPE', 'en', NULL, N'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'IS_ACTIVE', 'en', NULL, N'True if the handler is active.');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'MENU_ORDER', 'en', NULL, N'Sort order of Actions and Context Menu items');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'TABLE_NAME', 'en', NULL, N'Database object name, SQL-code name, or http-query name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'event_handlers', N'TARGET_WORKSHEET', 'en', NULL, N'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'object_translation', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'object_translation', N'LANGUAGE_NAME', 'en', NULL, N'Two-char language code');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'object_translation', N'TABLE_NAME', 'en', NULL, N'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'object_translation', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'object_translation', N'TRANSLATED_COMMENT', 'en', NULL, N'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'object_translation', N'TRANSLATED_DESC', 'en', NULL, N'Text for ScreenTips and SaveToDB_Desc named cells');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'object_translation', N'TRANSLATED_NAME', 'en', NULL, N'Translated name for Query List, Actions and Context Menus');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'parameter_values', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'parameter_values', N'PARAMETER_NAME', 'en', NULL, N'Column or parameter name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'parameter_values', N'SELECT_NAME', 'en', NULL, N'Database object name or name for SQL-code');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'parameter_values', N'SELECT_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'parameter_values', N'SELECT_TYPE', 'en', NULL, N'Database object type or CODE for SQL-code');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'parameter_values', N'TABLE_NAME', 'en', NULL, N'Database object name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'parameter_values', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'query_list', N'DELETE_PROCEDURE', 'en', NULL, N'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'query_list', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'query_list', N'INSERT_PROCEDURE', 'en', NULL, N'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'query_list', N'TABLE_NAME', 'en', NULL, N'Database object name or unique name for SQL-code and http-query');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'query_list', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'query_list', N'TABLE_TYPE', 'en', NULL, N'Database object type, CODE for SQL-code, or HTTP for http-query');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'query_list', N'UPDATE_PROCEDURE', 'en', NULL, N'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'table_formats', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'table_formats', N'TABLE_EXCEL_FORMAT_XML', 'en', NULL, N'Excel table format XML');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'table_formats', N'TABLE_NAME', 'en', NULL, N'Database object name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'table_formats', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'usp_update_table_format', N'ExcelFormatXML', 'en', NULL, N'Excel table format XML');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'usp_update_table_format', N'Name', 'en', NULL, N'Database object name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_dev', N'usp_update_table_format', N'Schema', 'en', NULL, N'Database object schema');

INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_column_translation', N'COLUMN_NAME', 'en', NULL, N'Column or parameter name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_column_translation', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_column_translation', N'LANGUAGE_NAME', 'en', NULL, N'Two-char language code');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_column_translation', N'TABLE_NAME', 'en', NULL, N'Database object name or NULL for entire schema scope');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_column_translation', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema or NULL for entire database scope');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_column_translation', N'TRANSLATED_DESC', 'en', NULL, N'Text for Excel table header comments and ribbon parameter SuperTips');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_column_translation', N'TRANSLATED_NAME', 'en', NULL, N'Translated name for Excel table headers and ribbon parameters');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'COLUMN_NAME', 'en', NULL, N'Column name or NULL to use the handler for entire table');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'EDIT_PARAMETERS', 'en', NULL, N'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'EVENT_NAME', 'en', NULL, N'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'HANDLER_NAME', 'en', NULL, N'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'HANDLER_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'HANDLER_TYPE', 'en', NULL, N'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'IS_ACTIVE', 'en', NULL, N'True if the handler is active.');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'MENU_ORDER', 'en', NULL, N'Sort order of Actions and Context Menu items');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'TABLE_NAME', 'en', NULL, N'Database object name, SQL-code name, or http-query name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_event_handlers', N'TARGET_WORKSHEET', 'en', NULL, N'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_description', N'LANGUAGE_NAME', 'en', N'Language', N'Two-char language code');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_description', N'TABLE_NAME', 'en', N'Object Name', N'Database object name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_description', N'TABLE_SCHEMA', 'en', N'Schema', N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_description', N'TRANSLATED_COMMENT', 'en', N'Comment', N'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_description', N'TRANSLATED_NAME', 'en', N'Name', N'Translated name for Query List, Actions and Context Menus');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_translation', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_translation', N'LANGUAGE_NAME', 'en', NULL, N'Two-char language code');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_translation', N'TABLE_NAME', 'en', NULL, N'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_translation', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_translation', N'TRANSLATED_COMMENT', 'en', NULL, N'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_translation', N'TRANSLATED_DESC', 'en', NULL, N'Text for ScreenTips and SaveToDB_Desc named cells');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_object_translation', N'TRANSLATED_NAME', 'en', NULL, N'Translated name for Query List, Actions and Context Menus');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_parameter_values', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_parameter_values', N'PARAMETER_NAME', 'en', NULL, N'Column or parameter name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_parameter_values', N'SELECT_NAME', 'en', NULL, N'Database object name or name for SQL-code');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_parameter_values', N'SELECT_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_parameter_values', N'SELECT_TYPE', 'en', NULL, N'Database object type or CODE for SQL-code');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_parameter_values', N'TABLE_NAME', 'en', NULL, N'Database object name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_parameter_values', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_query_list', N'DELETE_PROCEDURE', 'en', NULL, N'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_query_list', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_query_list', N'INSERT_PROCEDURE', 'en', NULL, N'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_query_list', N'TABLE_NAME', 'en', NULL, N'Database object name or unique name for SQL-code and http-query');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_query_list', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_query_list', N'TABLE_TYPE', 'en', NULL, N'Database object type, CODE for SQL-code, or HTTP for http-query');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_query_list', N'UPDATE_PROCEDURE', 'en', NULL, N'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_table_formats', N'ID', 'en', NULL, NULL);
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_table_formats', N'TABLE_EXCEL_FORMAT_XML', 'en', NULL, N'Excel table format XML');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_table_formats', N'TABLE_NAME', 'en', NULL, N'Database object name');
INSERT INTO [savetodb_dev].[column_translation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'savetodb_xls', N'view_table_formats', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');

INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_dev', N'column_translation', '<table name="savetodb_dev.column_translation"><columnFormats><column name="" property="ListObjectName" value="column_translation_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="COLUMN_NAME" property="Address" value="$F$7" type="String"/><column name="COLUMN_NAME" property="ColumnWidth" value="25.57" type="Double"/><column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double"/><column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double"/><column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String"/><column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="LANGUAGE_NAME" property="Address" value="$G$7" type="String"/><column name="LANGUAGE_NAME" property="ColumnWidth" value="19.57" type="Double"/><column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double"/><column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String"/><column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="LANGUAGE_NAME" property="Validation.ErrorMessage" value="The column requires values of the char(2) datatype." type="String"/><column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_NAME" property="Address" value="$H$7" type="String"/><column name="TRANSLATED_NAME" property="ColumnWidth" value="20.71" type="Double"/><column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_DESC" property="Address" value="$I$7" type="String"/><column name="TRANSLATED_DESC" property="ColumnWidth" value="70.71" type="Double"/><column name="TRANSLATED_DESC" property="VerticalAlignment" value="-4160" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Formula1" value="1024" type="String"/><column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_DESC" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(1024) datatype." type="String"/><column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$212,$F$7:$G$212" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="LANGUAGE_NAME" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="SortFields(4)" property="KeyfieldName" value="COLUMN_NAME" type="String"/><column name="SortFields(4)" property="SortOn" value="0" type="Double"/><column name="SortFields(4)" property="Order" value="1" type="Double"/><column name="SortFields(4)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_dev', N'event_handlers', '<table name="savetodb_dev.event_handlers"><columnFormats><column name="" property="ListObjectName" value="event_handlers_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="COLUMN_NAME" property="Address" value="$F$7" type="String"/><column name="COLUMN_NAME" property="ColumnWidth" value="18.57" type="Double"/><column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double"/><column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double"/><column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String"/><column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EVENT_NAME" property="Address" value="$G$7" type="String"/><column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double"/><column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="EVENT_NAME" property="Validation.Type" value="3" type="Double"/><column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String"/><column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the varchar(50) datatype." type="String"/><column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String"/><column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double"/><column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_NAME" property="Address" value="$I$7" type="String"/><column name="HANDLER_NAME" property="ColumnWidth" value="57.57" type="Double"/><column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_TYPE" property="Address" value="$J$7" type="String"/><column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double"/><column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double"/><column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String"/><column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_CODE" property="Address" value="$K$7" type="String"/><column name="HANDLER_CODE" property="ColumnWidth" value="45" type="Double"/><column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String"/><column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double"/><column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Formula1" value="128" type="String"/><column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean"/><column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="MENU_ORDER" property="Address" value="$M$7" type="String"/><column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double"/><column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double"/><column name="MENU_ORDER" property="Validation.Type" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Formula1" value="-2147483648" type="String"/><column name="MENU_ORDER" property="Validation.Formula2" value="2147483647" type="String"/><column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean"/><column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String"/><column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double"/><column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double"/><column name="IS_ACTIVE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="IS_ACTIVE" property="Address" value="$O$7" type="String"/><column name="IS_ACTIVE" property="ColumnWidth" value="11.43" type="Double"/><column name="IS_ACTIVE" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$446,$G$7:$G$446,$I$7:$I$446" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="EVENT_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="SortFields(4)" property="KeyfieldName" value="MENU_ORDER" type="String"/><column name="SortFields(4)" property="SortOn" value="0" type="Double"/><column name="SortFields(4)" property="Order" value="1" type="Double"/><column name="SortFields(4)" property="DataOption" value="0" type="Double"/><column name="SortFields(5)" property="KeyfieldName" value="HANDLER_NAME" type="String"/><column name="SortFields(5)" property="SortOn" value="0" type="Double"/><column name="SortFields(5)" property="Order" value="1" type="Double"/><column name="SortFields(5)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_dev', N'object_translation', '<table name="savetodb_dev.object_translation"><columnFormats><column name="" property="ListObjectName" value="object_translation_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="33.86" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="LANGUAGE_NAME" property="Address" value="$F$7" type="String"/><column name="LANGUAGE_NAME" property="ColumnWidth" value="19.57" type="Double"/><column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double"/><column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String"/><column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="LANGUAGE_NAME" property="Validation.ErrorMessage" value="The column requires values of the char(2) datatype." type="String"/><column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_NAME" property="Address" value="$G$7" type="String"/><column name="TRANSLATED_NAME" property="ColumnWidth" value="38" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_DESC" property="Address" value="$H$7" type="String"/><column name="TRANSLATED_DESC" property="ColumnWidth" value="70.71" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Formula1" value="255" type="String"/><column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_DESC" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String"/><column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_COMMENT" property="Address" value="$I$7" type="String"/><column name="TRANSLATED_COMMENT" property="ColumnWidth" value="70.71" type="Double"/><column name="TRANSLATED_COMMENT" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_COMMENT" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_COMMENT" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_COMMENT" property="Validation.Formula1" value="4000" type="String"/><column name="TRANSLATED_COMMENT" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_COMMENT" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_COMMENT" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_COMMENT" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(4000) datatype." type="String"/><column name="TRANSLATED_COMMENT" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_COMMENT" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="FormatConditions(1).ColumnsCount" value="3" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$F$167" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="LANGUAGE_NAME" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_dev', N'parameter_values', '<table name="savetodb_dev.parameter_values"><columnFormats><column name="" property="ListObjectName" value="parameter_values_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="26.29" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="PARAMETER_NAME" property="Address" value="$F$7" type="String"/><column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double"/><column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double"/><column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="PARAMETER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="PARAMETER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String"/><column name="SELECT_SCHEMA" property="ColumnWidth" value="17.29" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_NAME" property="Address" value="$H$7" type="String"/><column name="SELECT_NAME" property="ColumnWidth" value="34.86" type="Double"/><column name="SELECT_NAME" property="Validation.Type" value="6" type="Double"/><column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_NAME" property="Validation.Formula1" value="128" type="String"/><column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_TYPE" property="Address" value="$I$7" type="String"/><column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double"/><column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double"/><column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;VALUES;RANGE" type="String"/><column name="SELECT_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_CODE" property="Address" value="$J$7" type="String"/><column name="SELECT_CODE" property="ColumnWidth" value="70.71" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$63" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$63" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="7" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$63,$I$7:$I$63" type="String"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Priority" value="4" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_dev', N'query_list', '<table name="savetodb_dev.query_list"><columnFormats><column name="" property="ListObjectName" value="query_list_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="28.29" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_TYPE" property="Address" value="$F$7" type="String"/><column name="TABLE_TYPE" property="ColumnWidth" value="13.14" type="Double"/><column name="TABLE_TYPE" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_TYPE" property="Validation.Type" value="3" type="Double"/><column name="TABLE_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;CODE;HTTP;TEXT" type="String"/><column name="TABLE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_CODE" property="Address" value="$G$7" type="String"/><column name="TABLE_CODE" property="ColumnWidth" value="21.57" type="Double"/><column name="INSERT_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="INSERT_PROCEDURE" property="Address" value="$H$7" type="String"/><column name="INSERT_PROCEDURE" property="ColumnWidth" value="23.43" type="Double"/><column name="INSERT_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double"/><column name="INSERT_PROCEDURE" property="Validation.Type" value="6" type="Double"/><column name="INSERT_PROCEDURE" property="Validation.AlertStyle" value="1" type="Double"/><column name="INSERT_PROCEDURE" property="Validation.Operator" value="8" type="Double"/><column name="INSERT_PROCEDURE" property="Validation.Formula1" value="2000" type="String"/><column name="INSERT_PROCEDURE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="INSERT_PROCEDURE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="INSERT_PROCEDURE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="INSERT_PROCEDURE" property="Validation.ShowError" value="True" type="Boolean"/><column name="UPDATE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="UPDATE_PROCEDURE" property="Address" value="$I$7" type="String"/><column name="UPDATE_PROCEDURE" property="ColumnWidth" value="23.43" type="Double"/><column name="UPDATE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double"/><column name="UPDATE_PROCEDURE" property="Validation.Type" value="6" type="Double"/><column name="UPDATE_PROCEDURE" property="Validation.AlertStyle" value="1" type="Double"/><column name="UPDATE_PROCEDURE" property="Validation.Operator" value="8" type="Double"/><column name="UPDATE_PROCEDURE" property="Validation.Formula1" value="2000" type="String"/><column name="UPDATE_PROCEDURE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="UPDATE_PROCEDURE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="UPDATE_PROCEDURE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="UPDATE_PROCEDURE" property="Validation.ShowError" value="True" type="Boolean"/><column name="DELETE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="DELETE_PROCEDURE" property="Address" value="$J$7" type="String"/><column name="DELETE_PROCEDURE" property="ColumnWidth" value="23.43" type="Double"/><column name="DELETE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double"/><column name="DELETE_PROCEDURE" property="Validation.Type" value="6" type="Double"/><column name="DELETE_PROCEDURE" property="Validation.AlertStyle" value="1" type="Double"/><column name="DELETE_PROCEDURE" property="Validation.Operator" value="8" type="Double"/><column name="DELETE_PROCEDURE" property="Validation.Formula1" value="2000" type="String"/><column name="DELETE_PROCEDURE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="DELETE_PROCEDURE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="DELETE_PROCEDURE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="DELETE_PROCEDURE" property="Validation.ShowError" value="True" type="Boolean"/><column name="PROCEDURE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="PROCEDURE_TYPE" property="Address" value="$K$7" type="String"/><column name="PROCEDURE_TYPE" property="ColumnWidth" value="18.86" type="Double"/><column name="PROCEDURE_TYPE" property="Validation.Type" value="3" type="Double"/><column name="PROCEDURE_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="PROCEDURE_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="PROCEDURE_TYPE" property="Validation.Formula1" value="TABLE;PROCEDURE;CODE;MERGE" type="String"/><column name="PROCEDURE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="PROCEDURE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="PROCEDURE_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="PROCEDURE_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$37" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).NumberFormat" value="General" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$37" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(2).AppliesTo.Address" value="$E$7:$E$37" type="String"/><column name="TABLE_NAME" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(2).Priority" value="3" type="Double"/><column name="TABLE_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(2).NumberFormat" value="General" type="String"/><column name="TABLE_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_dev', N'table_formats', '<table name="savetodb_dev.table_formats"><columnFormats><column name="" property="ListObjectName" value="DevObjects_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="6" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="43.14" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_EXCEL_FORMAT_XML" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_EXCEL_FORMAT_XML" property="Address" value="$F$7" type="String"/><column name="TABLE_EXCEL_FORMAT_XML" property="ColumnWidth" value="70.71" type="Double"/><column name="TABLE_EXCEL_FORMAT_XML" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$103" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).NumberFormat" value="General" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$103" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="2" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="2" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/><column name="" property="PageSetup.PaperSize" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_xls', N'view_object_description', N'<table name="savetodb_xls.view_object_description"><columnFormats><column name="" property="ListObjectName" value="UserObjects_Table1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$7" type="String" /><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" /><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ID" property="Address" value="$C$7" type="String" /><column name="ID" property="ColumnWidth" value="0.08" type="Double" /><column name="ID" property="VerticalAlignment" value="-4160" type="Double" /><column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="LANGUAGE_NAME" property="Address" value="$D$7" type="String" /><column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" /><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="TABLE_SCHEMA" property="Address" value="$E$7" type="String" /><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" /><column name="TABLE_NAME" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="TABLE_NAME" property="Address" value="$F$7" type="String" /><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" /><column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TRANSLATED_NAME" property="Address" value="$G$7" type="String" /><column name="TRANSLATED_NAME" property="ColumnWidth" value="24.29" type="Double" /><column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" /><column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TRANSLATED_COMMENT" property="Address" value="$H$7" type="String" /><column name="TRANSLATED_COMMENT" property="ColumnWidth" value="114" type="Double" /><column name="TRANSLATED_COMMENT" property="VerticalAlignment" value="-4160" type="Double" /><column name="TRANSLATED_COMMENT" property="WrapText" value="True" type="Boolean" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /><column name="" property="PageSetup.PaperSize" value="1" type="Double" /></columnFormats></table>')

print N'SaveToDB Framework data have been added';
GO

print N'SaveToDB Framework has been installed';
GO
